require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module Finman
    module FinancialTransaction
      # DTO for create command of Credit note.
      class CreditNoteCreate < UU::OS::REST::DTO

        # Name of created Credit note. Required attribute. Cannot be null or empty.
        # Its value is automatically trimmed. Cannot be null nor empty string nor longer than 250 characters.
        # The create command fails otherwise.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # UESURI Account from opposite territory.
        # Usable only for interterritorial payments.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :account_from_opposite_territory;

        # Amount of the Credit note without vat. Required attribute.
        # Required attribute. Cannot be null.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Credit note with vat.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # UESURI of the business case of non-control side of paynment.
        # Required attribute. Cannot be null.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :counterparty_business_case_uri

        # Number of client account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String]
        # @return [String]
        attr_accessor :client_account_number

        # UESURI of client account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_account_uri

        # UESURI of client business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_business_case_from_opposite_territory

        # Description for client side.
        # @param [String]
        # @return [String]
        attr_accessor :client_description

        # UESURI of client financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :client_financial_category_uri

        # Code of credit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_side_currency

        # Code of client side currency.
        # @param [String]
        # @return [String]
        attr_accessor :client_side_currency

        # Code of transaction currency.
        # @param [String]
        # @return [String]
        attr_accessor :transaction_currency

        # Vat date of the transaction.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :vat_date

        # Number of supplier account.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :supplier_account_number

        # UESURI of supplier account artifact.
        # Either number or UESURI of account must be set. Not both of them.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_account_uri

        # UESURI of supplier business case from opposite territory.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_business_case_from_opposite_territory

        # Description for supplier side.
        # @param [String]
        # @return [String]
        attr_accessor :supplier_description

        # UESURI of supplier financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :supplier_financial_category_uri

        # Date the transaction is due to be paid.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the transaction is expected to be payed to.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Type of financial transaction. Item from enumeration {UU::Finman::FinancialTransaction::FinancialTransactionType}.
        # Cannot be null. Following rules must be obeyed:
        #
        # If both UESURI of debit and credit account are set, then:
        # - if both accounts are Bank accounts, FinancialTransactionType.NONCASH must be set.
        # - if at least one account is Cash account, FinancialTransactionType.CASH must be set.
        # Otherwise any choice can be set.
        # @param [String, FinancialTransactionCreate]
        # @return [String]
        attr_accessor :financial_transaction_type


        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of credit note.
        # Ignored for transfers.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # Possible values: true or false. True indicates type of credit note as Outgoing, false as Incoming.
        # If not set, default value is 'true'.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :is_credit_note_outgoing

        # Date of invoicing to the counterparty.
        # Required attribute. Cannot be null.
        # @param [String, Time]
        # @return [String]
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Possible values: true or false. Specifies whether is it needed to approve the credit note by competent
        # manager.
        # If not set, default value is 'false'.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :request_approval_by_manager

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # Either amount with vat or vat rate must be set.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Possible values: true or false. Specifies whether it is needed to confirm the acceptance of the credit
        # note by client's accountant.
        # If not set, default value is 'false'.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :wait_for_acceptance_by_accountant

        # Dry run. If true, all validations will be processed, but credit note
        # will not be created.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :dry_run

        # Explicit exchange rate. Can be set only by role cast in Accounting Authorities.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_exchange_rate

        # Explicit amount with VAT in opposite side currency. Can be set only by role cast in Accounting Authorities.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_amount

        # Type of advanced state
        # @param [String, FinancialTransactionState]
        # @return [String]
        attr_accessor :financial_transaction_state

        # Related links(URI, label) in JSON format.
        # @param [String]
        # @return [String]
        attr_accessor :related_links

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def account_from_opposite_territory
          attributes[:accountFromOppositeTerritory]
        end

        def account_from_opposite_territory=(val)
          attributes[:accountFromOppositeTerritory] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def counterparty_business_case_uri
          attributes[:counterpartyBusinessCaseUri]
        end

        def counterparty_business_case_uri=(val)
          if val
            attributes[:counterpartyBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:counterpartyBusinessCaseUri] = nil
          end
        end

        def client_account_number
          attributes[:clientAccountNumber]
        end

        def client_account_number=(val)
          attributes[:clientAccountNumber] = val
        end

        def client_account_uri
          attributes[:clientAccountUri]
        end

        def client_account_uri=(val)
          if val
            attributes[:clientAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:clientAccountUri] = nil
          end
        end

        def client_business_case_from_opposite_territory
          attributes[:clientBusinessCaseFromOppositeTerritory]
        end

        def client_business_case_from_opposite_territory=(val)
          attributes[:clientBusinessCaseFromOppositeTerritory] = val
        end

        def client_description
          attributes[:clientDescription]
        end

        def client_description=(val)
          attributes[:clientDescription] = val
        end

        def client_financial_category_uri
          attributes[:clientFinancialCategoryUri]
        end

        def client_financial_category_uri=(val)
          attributes[:clientFinancialCategoryUri] = val
        end

        def supplier_side_currency
          attributes[:supplierSideCurrency]
        end

        def supplier_side_currency=(val)
          attributes[:supplierSideCurrency] = val
        end

        def client_side_currency
          attributes[:clientSideCurrency]
        end

        def client_side_currency=(val)
          attributes[:clientSideCurrency] = val
        end

        def transaction_currency
          attributes[:transactionCurrency]
        end

        def transaction_currency=(val)
          attributes[:transactionCurrency] = val
        end

        def vat_date
          attributes[:vatDate]
        end

        def vat_date=(val)
          attributes[:vatDate] = val
        end

        def supplier_account_number
          attributes[:supplierAccountNumber]
        end

        def supplier_account_number=(val)
          attributes[:supplierAccountNumber] = val
        end

        def supplier_account_uri
          attributes[:supplierAccountUri]
        end

        def supplier_account_uri=(val)
          if val
            attributes[:supplierAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:supplierAccountUri] = nil
          end
        end

        def supplier_business_case_from_opposite_territory
          attributes[:supplierBusinessCaseFromOppositeTerritory]
        end

        def supplier_business_case_from_opposite_territory=(val)
          attributes[:supplierBusinessCaseFromOppositeTerritory] = val
        end

        def supplier_description
          attributes[:supplierDescription]
        end

        def supplier_description=(val)
          attributes[:supplierDescription] = val
        end

        def supplier_financial_category_uri
          attributes[:supplierFinancialCategoryUri]
        end

        def supplier_financial_category_uri=(val)
          attributes[:supplierFinancialCategoryUri] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def is_credit_note_outgoing
          attributes[:isCreditNoteOutgoing]
        end

        def is_credit_note_outgoing=(val)
          attributes[:isCreditNoteOutgoing] = val
        end

        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def request_approval_by_manager
          attributes[:requestApprovalByManager]
        end

        def request_approval_by_manager=(val)
          attributes[:requestApprovalByManager] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def wait_for_acceptance_by_accountant
          attributes[:waitForAcceptanceByAccountant]
        end

        def wait_for_acceptance_by_accountant=(val)
          attributes[:waitForAcceptanceByAccountant] = val
        end

        def dry_run
          attributes[:dryRun]
        end

        def dry_run=(val)
          attributes[:dryRun] = val
        end

        def explicit_exchange_rate
          attributes[:explicitExchangeRate]
        end

        def explicit_exchange_rate=(val)
          attributes[:explicitExchangeRate] = val
        end

        def explicit_amount
          attributes[:explicitAmount]
        end

        def explicit_amount=(val)
          attributes[:explicitAmount] = val
        end

        def financial_transaction_state
          attributes[:financialTransactionState]
        end

        def financial_transaction_state=(val)
          attributes[:financialTransactionState] = val
        end

        def related_links
          attributes[:relatedLinks]
        end

        def related_links=(val)
          attributes[:relatedLinks] = val
        end

      end
    end
  end
end
